==> knative-model-6.0.0-sources.jar: io/fabric8/knative/messaging/v1/InMemoryChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import java.lang.Deprecated;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusBuilder;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface InMemoryChannelStatusFluent<A extends InMemoryChannelStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public InMemoryChannelStatusFluent.AddressNested<A> withNewAddress();
  public InMemoryChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public InMemoryChannelStatusFluent.AddressNested<A> editAddress();
  public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddress();
  public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public InMemoryChannelStatusFluent.ConditionsNested<A> addNewCondition();
  public InMemoryChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public InMemoryChannelStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public InMemoryChannelStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public InMemoryChannelStatusFluent.ConditionsNested<A> editFirstCondition();
  public InMemoryChannelStatusFluent.ConditionsNested<A> editLastCondition();
  public InMemoryChannelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeadLetterChannel instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getDeadLetterChannel();
  public KReference buildDeadLetterChannel();
  public A withDeadLetterChannel(KReference deadLetterChannel);
  public Boolean hasDeadLetterChannel();
  public A withNewDeadLetterChannel(String apiVersion,String kind,String name,String namespace);
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannel();
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannelLike(KReference item);
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editDeadLetterChannel();
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannel();
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannelLike(KReference item);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public A addToSubscribers(Integer index,SubscriberStatus item);
  public A setToSubscribers(Integer index,SubscriberStatus item);
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A addAllToSubscribers(Collection<SubscriberStatus> items);
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A removeAllFromSubscribers(Collection<SubscriberStatus> items);
  public A removeMatchingFromSubscribers(Predicate<SubscriberStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberStatus> getSubscribers();
  public List<SubscriberStatus> buildSubscribers();
  public SubscriberStatus buildSubscriber(Integer index);
  public SubscriberStatus buildFirstSubscriber();
  public SubscriberStatus buildLastSubscriber();
  public SubscriberStatus buildMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public Boolean hasMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public A withSubscribers(List<SubscriberStatus> subscribers);
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... subscribers);
  public Boolean hasSubscribers();
  public A addNewSubscriber(String message,Long observedGeneration,String ready,String uid);
  public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriber();
  public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberStatus item);
  public InMemoryChannelStatusFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberStatus item);
  public InMemoryChannelStatusFluent.SubscribersNested<A> editSubscriber(Integer index);
  public InMemoryChannelStatusFluent.SubscribersNested<A> editFirstSubscriber();
  public InMemoryChannelStatusFluent.SubscribersNested<A> editLastSubscriber();
  public InMemoryChannelStatusFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<InMemoryChannelStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<InMemoryChannelStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DeadLetterChannelNested<N> extends Nested<N>,KReferenceFluent<InMemoryChannelStatusFluent.DeadLetterChannelNested<N>>{
    public N and();
    public N endDeadLetterChannel();
    
  }
  public interface SubscribersNested<N> extends Nested<N>,SubscriberStatusFluent<InMemoryChannelStatusFluent.SubscribersNested<N>>{
    public N and();
    public N endSubscriber();
    
  }
  
}

==> knative-model-6.3.1-sources.jar: io/fabric8/knative/messaging/v1/InMemoryChannelStatusFluent.java <==
package io.fabric8.knative.messaging.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReference;
import java.lang.Deprecated;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusBuilder;
import java.util.Iterator;
import java.util.List;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatusFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.KReferenceFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface InMemoryChannelStatusFluent<A extends InMemoryChannelStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public InMemoryChannelStatusFluent.AddressNested<A> withNewAddress();
  public InMemoryChannelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public InMemoryChannelStatusFluent.AddressNested<A> editAddress();
  public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddress();
  public InMemoryChannelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public InMemoryChannelStatusFluent.ConditionsNested<A> addNewCondition();
  public InMemoryChannelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public InMemoryChannelStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public InMemoryChannelStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public InMemoryChannelStatusFluent.ConditionsNested<A> editFirstCondition();
  public InMemoryChannelStatusFluent.ConditionsNested<A> editLastCondition();
  public InMemoryChannelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeadLetterChannel instead.
   * @return The buildable object.
   */
  @Deprecated
  public KReference getDeadLetterChannel();
  public KReference buildDeadLetterChannel();
  public A withDeadLetterChannel(KReference deadLetterChannel);
  public Boolean hasDeadLetterChannel();
  public A withNewDeadLetterChannel(String apiVersion,String group,String kind,String name,String namespace);
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannel();
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> withNewDeadLetterChannelLike(KReference item);
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editDeadLetterChannel();
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannel();
  public InMemoryChannelStatusFluent.DeadLetterChannelNested<A> editOrNewDeadLetterChannelLike(KReference item);
  public String getDeadLetterSinkUri();
  public A withDeadLetterSinkUri(String deadLetterSinkUri);
  public Boolean hasDeadLetterSinkUri();
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public A addToSubscribers(Integer index,SubscriberStatus item);
  public A setToSubscribers(Integer index,SubscriberStatus item);
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A addAllToSubscribers(Collection<SubscriberStatus> items);
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... items);
  public A removeAllFromSubscribers(Collection<SubscriberStatus> items);
  public A removeMatchingFromSubscribers(Predicate<SubscriberStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberStatus> getSubscribers();
  public List<SubscriberStatus> buildSubscribers();
  public SubscriberStatus buildSubscriber(Integer index);
  public SubscriberStatus buildFirstSubscriber();
  public SubscriberStatus buildLastSubscriber();
  public SubscriberStatus buildMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public Boolean hasMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public A withSubscribers(List<SubscriberStatus> subscribers);
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberStatus... subscribers);
  public Boolean hasSubscribers();
  public A addNewSubscriber(String message,Long observedGeneration,String ready,String uid);
  public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriber();
  public InMemoryChannelStatusFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberStatus item);
  public InMemoryChannelStatusFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberStatus item);
  public InMemoryChannelStatusFluent.SubscribersNested<A> editSubscriber(Integer index);
  public InMemoryChannelStatusFluent.SubscribersNested<A> editFirstSubscriber();
  public InMemoryChannelStatusFluent.SubscribersNested<A> editLastSubscriber();
  public InMemoryChannelStatusFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberStatusBuilder> predicate);
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<InMemoryChannelStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<InMemoryChannelStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DeadLetterChannelNested<N> extends Nested<N>,KReferenceFluent<InMemoryChannelStatusFluent.DeadLetterChannelNested<N>>{
    public N and();
    public N endDeadLetterChannel();
    
  }
  public interface SubscribersNested<N> extends Nested<N>,SubscriberStatusFluent<InMemoryChannelStatusFluent.SubscribersNested<N>>{
    public N and();
    public N endSubscriber();
    
  }
  
}
